@@ -152,6 +152,14 @@ class TreeOverview(BaseSubcomponent, BaseDraggable, QtWidgets.QTreeWidget):
         target_treeitem = self.currentItem()
         if target_treeitem is not None:
             target_treeitem.copy_linked()
+            
+    def copy_item_shallow(self):
+        """Copies the currently selected treeitem to the clipboard (if
+        supported by the treeitem) as a shallow copy.
+        """        
+        target_treeitem = self.currentItem()
+        if target_treeitem is not None:
+            target_treeitem.copy_shallow()
 
     def paste_item(self):
         """Pastes the clipboard onto the currently selected treeitem (if
@@ -177,22 +185,6 @@ class TreeOverview(BaseSubcomponent, BaseDraggable, QtWidgets.QTreeWidget):
         if target_treeitem is not None:
             target_treeitem.permanently_delete()
 
-    def create_linked_copy(self):
-        """Creates a linked copy of the currently selected item (if supported
-        by the treeitem).
-        """
-        target_treeitem = self.currentItem()
-        if target_treeitem is not None:
-            target_treeitem.create_linked_copy()
-
-    def create_unlinked_copy(self):
-        """Creates an unlinked copy of the currently selected item (if
-        supported by the treeitem).
-        """
-        target_treeitem = self.currentItem()
-        if target_treeitem is not None:
-            target_treeitem.create_unlinked_copy()
-
     def select_item(self, name, open_tab=True):
         """Selects all items that match the specified name.
 
@@ -408,6 +400,7 @@ class TreeOverview(BaseSubcomponent, BaseDraggable, QtWidgets.QTreeWidget):
             return
         # Only accept existing-item drops from this application
         if data['application-id'] != self.main_window._id():
+            self.notify(_('Cannot copy linked copies between windows. Use unlinked copy instead.'))
             oslogger.debug('Drop ignored: from different instance')
             if e is not None:
                 e.ignore()
